/*--------------------------------------------------------------------------+
$Id$
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.extension.data;

import org.eclipse.core.runtime.Assert;
import org.fortiss.tooling.kernel.model.ExecutionConfiguration;
import org.fortiss.tooling.kernel.model.ExecutionConfigurationPart;

/**
 * This class implements an {@link ITransformationContext} with a reference to
 * an {@link ExecutionConfiguration}. Instances of this class are provided to
 * the transformation service during the search for a transformation chain
 * during target execution.
 * 
 * @author hoelzl
 * @author $Author$
 * @version $Rev$
 * @ConQAT.Rating YELLOW Hash: 782B0D1DA676B41BB134782CFD9A2B74
 */
public final class ExecutionConfigTransformationContext implements
		ITransformationContext {

	/** Stores the execution configuration reference. */
	private final ExecutionConfiguration config;

	/** Constructor. */
	public ExecutionConfigTransformationContext(ExecutionConfiguration config) {
		Assert.isNotNull(config);
		this.config = config;
	}

	/** Returns the execution configuration. */
	public ExecutionConfiguration getConfiguration() {
		return config;
	}

	/**
	 * Returns the first execution configuration part with the given class or
	 * <code>null</code> if no such part exists.
	 */
	public ExecutionConfigurationPart getConfigurationPart(
			Class<? extends ExecutionConfigurationPart> clazz) {
		for (ExecutionConfigurationPart part : config
				.getConfigurationPartsList()) {
			if (clazz.isInstance(part)) {
				return part;
			}
		}
		return null;
	}
}
